# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _
from shortuuidfield import ShortUUIDField


class BaseModelMixin(models.Model):
    status = models.BooleanField(_(u'状态'), default=True, help_text=_(u'状态'), db_index=True)
    created_at = models.DateTimeField(_(u'创建时间'), auto_now_add=True, editable=True, help_text=_(u'创建时间'))
    updated_at = models.DateTimeField(_(u'更新时间'), auto_now=True, editable=True, help_text=_(u'更新时间'))

    class Meta:
        abstract = True


class StockInfo(BaseModelMixin):
    stock_id = ShortUUIDField(_(u'Stock唯一标识'), max_length=32, blank=True, null=True, help_text=u'Stock唯一标识', db_index=True)

    vendorCode = models.CharField(_(u'供应商简码'), max_length=8, blank=True, null=True, help_text=u'供应商简码')
    vendorName = models.CharField(_(u'供应商名称'), max_length=32, blank=True, null=True, help_text=u'供应商名称')
    vendorProductId = models.CharField(_(u'供应商商品ID'), max_length=32, blank=True, null=True, help_text=u'SKU', db_index=True)
    vendorProductName = models.CharField(_(u'供应商商品名称'), max_length=255, blank=True, null=True, help_text=u'供应商商品名称')

    storeId = models.CharField(_(u'供应商仓库ID'), max_length=8, blank=True, null=True, help_text=u'供应商仓库ID')
    storeName = models.CharField(_(u'供应商仓库名称'), max_length=32, blank=True, null=True, help_text=u'供应商仓库名称')
    # 分仓库存数量=库存总量，预计库存数量=预计库存总量
    quantity = models.IntegerField(_(u'分仓库存数量'), default=0, help_text=u'分仓库存数量')
    estimateQuantity = models.IntegerField(_(u'预计库存数量'), default=0, help_text=u'预计库存数量')

    # Tamron 填写
    inventoryDate = models.DateTimeField(_(u'库存日期'), blank=True, null=True, help_text=_(u'库存日期'))
    totalQuantity = models.IntegerField(_(u'库存总量'), default=0, help_text=u'库存总量')
    estimateDate = models.DateTimeField(_(u'预计库存日期'), blank=True, null=True, help_text=_(u'预计库存日期'))
    totalEstimateQuantity = models.IntegerField(_(u'预计库存总量'), default=0, help_text=u'预计库存总量')
    costPrice = models.IntegerField(_(u'进价'), default=0, help_text=u'进价')

    class Meta:
        verbose_name = _(u'1、库存数据调整')
        verbose_name_plural = _(u'1、库存数据调整')

    def __unicode__(self):
        return u'{0.vendorProductId}'.format(self)


class StockSendInfo(BaseModelMixin):
    submit = models.BooleanField(_(u'确认提交'), default=True, help_text=_(u'确认提交'))

    class Meta:
        verbose_name = _(u'2、库存数据提交')
        verbose_name_plural = _(u'2、库存数据提交')

    def __unicode__(self):
        return u'库存数据提交'
